==> mariadb-connector-java_2.4.2.orig.tar.xz: mariadb-connector-j-2.4.2/src/test/java/org/mariadb/jdbc/AutoReconnectTest.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2019 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.SQLNonTransientConnectionException;
import java.sql.SQLTransientConnectionException;
import java.sql.Statement;

import org.junit.Assert;
import org.junit.Assume;
import org.junit.Test;

public class AutoReconnectTest extends BaseTest {

  @Test
  public void autoReconnect() throws SQLException, InterruptedException {
    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
    try (Connection conn = setConnection("&autoReconnect")) {
      Statement stmt = conn.createStatement();
      stmt.executeQuery("SELECT 1");

      stmt.execute("SET SESSION wait_timeout = 1");
      Thread.sleep(3000);

      try {
        stmt.executeQuery("SELECT 2");
      } catch (SQLTransientConnectionException e) {
        Assert.fail("Must have send a SQLNonTransientConnectionException !");
      } catch (SQLNonTransientConnectionException e) {
        try {
          stmt.executeQuery("SELECT 3");
        } catch (SQLException ee) {
          ee.printStackTrace();
          Assert.fail("Must have reconnect automatically !");
        }
      } catch (SQLException e) {
        e.printStackTrace();
        Assert.fail("Must have reconnect automatically !");
      }
    }
  }

  @Test
  public void autoReconnectPing() throws SQLException, InterruptedException {
    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
    try (Connection conn = setConnection("&autoReconnect")) {
      Statement stmt = conn.createStatement();
      stmt.executeQuery("SELECT 1");

      stmt.execute("SET SESSION wait_timeout = 1");
      Thread.sleep(30000);

      try {
        conn.isValid(0);
      } catch (SQLTransientConnectionException e) {
        Assert.fail("Must have send a SQLNonTransientConnectionException !");
      } catch (SQLNonTransientConnectionException e) {
        try {
          stmt.executeQuery("SELECT 3");
        } catch (SQLException ee) {
          ee.printStackTrace();
          Assert.fail("Must have reconnect automatically !");
        }
      } catch (SQLException e) {
        e.printStackTrace();
        Assert.fail("Must have reconnect automatically !");
      }
    }
  }
}

==> mariadb-connector-java_2.5.3.orig.tar.xz: mariadb-connector-j-2.5.3/src/test/java/org/mariadb/jdbc/AutoReconnectTest.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2019 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc;

import org.junit.*;

import java.sql.*;

public class AutoReconnectTest extends BaseTest {

  @Test
  public void autoReconnect() throws SQLException, InterruptedException {
    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
    try (Connection conn = setConnection("&autoReconnect")) {
      Statement stmt = conn.createStatement();
      stmt.executeQuery("SELECT 1");

      stmt.execute("SET SESSION wait_timeout = 1");
      Thread.sleep(3000);

      try {
        stmt.executeQuery("SELECT 2");
      } catch (SQLTransientConnectionException e) {
        Assert.fail("Must have send a SQLNonTransientConnectionException !");
      } catch (SQLNonTransientConnectionException e) {
        try {
          stmt.executeQuery("SELECT 3");
        } catch (SQLException ee) {
          ee.printStackTrace();
          Assert.fail("Must have reconnect automatically !");
        }
      } catch (SQLException e) {
        e.printStackTrace();
        Assert.fail("Must have reconnect automatically !");
      }
    }
  }

  @Test
  public void autoReconnectPing() throws SQLException, InterruptedException {
    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null);
    try (Connection conn = setConnection("&autoReconnect")) {
      Statement stmt = conn.createStatement();
      stmt.executeQuery("SELECT 1");

      stmt.execute("SET SESSION wait_timeout = 1");
      Thread.sleep(30000);

      try {
        conn.isValid(0);
      } catch (SQLTransientConnectionException e) {
        Assert.fail("Must have send a SQLNonTransientConnectionException !");
      } catch (SQLNonTransientConnectionException e) {
        try {
          stmt.executeQuery("SELECT 3");
        } catch (SQLException ee) {
          ee.printStackTrace();
          Assert.fail("Must have reconnect automatically !");
        }
      } catch (SQLException e) {
        e.printStackTrace();
        Assert.fail("Must have reconnect automatically !");
      }
    }
  }
}
